Files
TheRock/debug-tools/rocgdb/source/gdb/testsuite/gdb.rocm/deref-scoped-pointer.cpp
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

91 lines
2.7 KiB
C++

/* Copyright 2023-2024 Free Software Foundation, Inc.
Copyright (C) 2023-2024 Advanced Micro Devices, Inc. All rights reserved.
This file is part of GDB.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>. */
#include <hip/hip_runtime.h>
#include <cassert>
#include <stdio.h>
#include <stdlib.h>
#define CHECK(cmd) \
{ \
hipError_t error = cmd; \
if (error != hipSuccess) \
{ \
fprintf (stderr, "error: '%s'(%d) at %s:%d\n", \
hipGetErrorString (error), error, __FILE__, __LINE__); \
exit (EXIT_FAILURE); \
} \
}
__device__ static void
done ()
{
}
/* This is initialized by the kernel function below. */
__device__ size_t *global_ptr = nullptr;
/* This is initialized by GDB. */
__device__ size_t *global_ptr2 = nullptr;
__global__ void
kernel ()
{
size_t local_var = blockIdx.x * blockDim.x + threadIdx.x;
/* This will be zero for the first HIP thread, or lane. */
if (local_var == 0)
global_ptr = &local_var;
/* Ensure thread 0 has assigned to global_ptr before the other
thread attempts to read it. Even though the lanes are in the
same wave, this prevents the compiler from restructuring the
control flow graph in a way that would break the test. */
__syncthreads ();
/* This is just to confirm how dereferencing the pointer from
different lanes yield a different value. GDB should behave the
same. */
assert (global_ptr != nullptr);
printf ("global_ptr=%p, *global_ptr=%zx\n", global_ptr, *global_ptr);
done (); /* set breakpoint here */
/* Convenience nullptr check useful if you run the program manually
or skip part of the testcase. */
if (global_ptr2 != nullptr)
{
printf ("global_ptr2=%p, *global_ptr2=%zx\n", global_ptr2, *global_ptr2);
/* GDB made global_ptr2 point to &local_var too. If GDB wrote
to global_ptr2 correctly, this should pass. */
assert (global_ptr == global_ptr2);
}
else
printf ("global_ptr2=nullptr\n");
}
int
main ()
{
/* We only need more than one lane. Two is sufficient. */
kernel<<<dim3 (1), dim3 (2)>>> ();
CHECK (hipDeviceSynchronize ());
return 0;
}